@@ -1508,7 +1508,7 @@ List inferHyperparam(NumericMatrix transMatr = NumericMatrix(), NumericVector sc
 //'  it fits the underlying Markov chain distribution using either MLE (also using a 
 //'  Laplacian smoother), bootstrap or by MAP (Bayesian) inference.
 //'  
-//' @param data A character list.
+//' @param data It can be a character vector or a nx2 matrix or a nx2 data frame or a list
 //' @param method Method used to estimate the Markov chain. Either "mle", "map", "bootstrap" or "laplace"
 //' @param byrow it tells whether the output Markov chain should show the transition probabilities by row.
 //' @param nboot Number of bootstrap replicates in case "bootstrap" is used.
@@ -1523,7 +1523,7 @@ List inferHyperparam(NumericMatrix transMatr = NumericMatrix(), NumericVector sc
 //'                   default value of 1 is assigned to each parameter. This must be of size kxk 
 //'                   where k is the number of states in the chain and the values should typically 
 //'                   be non-negative integers.                        
-//' @param stringchar Equivalent to data. It can be a nx2 matrix or a character vector or a list
+//' @param stringchar It can be a nx2 matrix or a character vector or a list
 //' @param toRowProbs converts a sequence matrix into a probability matrix
 //' @param sanitize put 1 in all rows having rowSum equal to zero
 //' @param possibleStates Possible states which are not present in the given sequence
@@ -1563,6 +1563,11 @@ List inferHyperparam(NumericMatrix transMatr = NumericMatrix(), NumericVector sc
 //' # There will be only a (a,b) transition        
 //' na.sequenceMatr <- createSequenceMatrix(na.sequence, sanitize = FALSE)
 //' mcFitMLE <- markovchainFit(data = na.sequence)
+//' 
+//' # data can be a list of character vectors
+//' sequences <- list(x = c("a", "b", "a"), y = c("b", "a", "b", "a", "c"))
+//' mcFitMap <- markovchainFit(sequences, method = "map")
+//' mcFitMle <- markovchainFit(sequences, method = "mle")
 //' @rdname markovchainFit
 //' 
 //' @export
@@ -1620,7 +1625,11 @@ List markovchainFit(SEXP data, String method = "mle", bool byrow = true, int nbo
   	}
   }
   else if(TYPEOF(data) == VECSXP) { 
-    out = _mcFitMle(data, byrow, confidencelevel, sanitize, possibleStates);
+    if(method == "mle") {
+      out = _mcFitMle(data, byrow, confidencelevel, sanitize, possibleStates);  
+    } else if(method == "map") {
+      out = _mcFitMap(data, byrow, confidencelevel, hyperparam, sanitize, possibleStates);
+    }
   }
   else {
     if(method == "mle") {
